/**
 * @(#) ServiceEndpoint.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ServiceEndpoint.java 221 2006-04-14 12:45:33Z alouis $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.servicedesc;

/**
 * Reference to an endpoint, used to refer an endpoint as well as query
 * information about the endpoint.
 * <p>
 * An endpoint is an addressable entity in the JBI system, used for accessing
 * the provider of a specific service.
 * <p>
 * This interface is implemented by both the JBI implementation and JBI
 * components, in the following use cases:
 * <ul>
 *   <li><b>Activated endpoints</b>: created by JBI implementation.
 *   <li><b>Internal endpoints from endpoint resolution</b>: created by the
 *   component implementation.
 *   <li><b>Registered external endpoints</b>: created by the component
 *   implementation.
 * </ul>
 * <p>
 * See the JBI Specification for details on requirements imposed on components
 * in the latter two use cases.
 * 
 * @author JSR208 Expert Group
 */
public interface ServiceEndpoint {

	/**
	 * Get a reference to this endpoint, using an endpoint reference vocabulary
     * that is known to the provider.
     * 
     * @param operationName
     *            the name of the operation to be performed by a consumer of the
     *            generated EPR; <code>null</**
     * @return endpoint reference as an XML fragment; <code>null</code> if the
     *         provider does not support such references
     */
	public org.w3c.dom.DocumentFragment getAsReference(
			javax.xml.namespace.QName operationName);

	/**
     * Returns the endpoint name of this reference.
     * 
     * @return endpoint name; must be non-null and non-empty
     */
	public java.lang.String getEndpointName();

	/**
	 * TODO getInterfaces not implemented
     * Get the qualified names of all the interfaces implemented by this service
     * endpoint.
     * 
     * @return array of all interfaces implemented by this service endpoint;
     *         must be non-null and non-empty
     */
	public javax.xml.namespace.QName[] getInterfaces();

	/**
     * Returns the service name of this reference.
     * 
     * @return qualified service name; must be non-null
     */
	public javax.xml.namespace.QName getServiceName();
}
